<?php 
/**
 * app7 functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package WordPress
 * @subpackage App7
 * @since 1.0
 */

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
*/

if(!function_exists( "app7_setup" )){
	function app7_setup(){

		// laod theme text domain
		load_theme_textdomain( 'app7', get_template_directory() . '/languages' );

		// theme support 
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'custom-header' );
		add_theme_support( 'custom-background' );
		add_theme_support( 'post-thumbnails' );

		// This theme styles the visual editor to resemble the theme style
		add_editor_style( 'css/custom-editor-style.css' );

		// add image size
		add_image_size( 'tl-screenshots-thumbnail', 300, 533, true );
		add_image_size( 'tl-client-two-thumb', 150, 150, true );
		add_image_size( 'tl-client-thumb', 85, 85, true );
		add_image_size( 'tl-team-thumb', 150, 150, true );
		add_image_size( 'tl-blog-thumb', 750, 433, true );
		add_image_size( 'tl-blog-thumb', 750, 433, true );
		add_image_size( 'tl-widget-recent-post-thumb', 80, 80, true );

		// Resister Nav Menu
		register_nav_menus(array(
			'main_menu'		=> esc_html__( 'Main Menu', 'app7' ),
		));

		// Set the default content width.
		$GLOBALS['content_width'] = 750;
		
		// Enable support for Post Formats.
		add_theme_support( 'post-formats', array(
			'aside',
			'image',
			'video',
			'quote',
			'link',
			'gallery',
			'audio',
		) );


	}
}
add_action( 'after_setup_theme', 'app7_setup' );

/*
|-----------------------------------------------
|	Gutenberg Support File Iclude
|-----------------------------------------------
*/ 
	// Gutenberg support
	add_theme_support( 'wp-block-styles' );
    add_theme_support( 'align-wide' );
    add_theme_support( 'responsive-embeds' );

	// Gutenberg Color Palette
    add_theme_support( 'editor-color-palette', array(
        array(
            'name' => esc_html__( 'Primary', 'app7' ),
            'slug' => 'primary',
            'color' => '#313131',
        ),
        array(
            'name' => esc_html__( 'Secondary', 'app7' ),
            'slug' => 'secondary',
            'color' => '#606060',
        ),
        array(
            'name' => esc_html__( 'Green Sea', 'app7' ),
            'slug' => 'green-sea',
            'color' => '#1abc9c',
        ),
        array(
            'name' => esc_html__( 'Green Emarald', 'app7' ),
            'slug' => 'green-emarald',
            'color' => '#2ecc71',
        ),
        array(
            'name' => esc_html__( 'Amethyst', 'app7' ),
            'slug' => 'amethyst',
            'color' => '#9b59b6',
        ),
        array(
            'name' => esc_html__( 'Asphalt', 'app7' ),
            'slug' => 'asphalt',
            'color' => '#34495e',
        ),
        array(
            'name' => esc_html__( 'SunFlower', 'app7' ),
            'slug' => 'sunflower',
            'color' => '#f1c40f',
        ),
        array(
            'name' => esc_html__( 'Orange', 'app7' ),
            'slug' => 'orange',
            'color' => '#f39c12',
        ),
        array(
            'name' => esc_html__( 'Alizarin', 'app7' ),
            'slug' => 'alizarin',
            'color' => '#e74c3c',
        )
    ) );

	// Registers an editor stylesheet for Gutenberg.

	if( function_exists( 'register_block_type' ) ){
	    function app7_font_scripts() {
			wp_enqueue_style( 'app7-web-font', app7_web_fonts_url('Montserrat:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i|Open Sans:300,300i,400,400i,600,600i,700,700i,800,800i|Raleway:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i'), array());
	        wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css', array(), false, 'all' );
	        wp_enqueue_style( 'editor-style', get_theme_file_uri( '/css/editor-style.css' ) );
	    }
	    add_action( 'admin_enqueue_scripts', 'app7_font_scripts' );
	}


/*
|----------------------------------------------
|	Enqueue scripts and styles.
|----------------------------------------------
*/
if(!function_exists("app7_scripts")){
	function app7_scripts(){

		// all styelsheets
		wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.css', array(), false, 'all' );
		wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css', array(), false, 'all' );
		wp_enqueue_style( 'owl-carousel', get_template_directory_uri() . '/css/owl.carousel.css', array(), false, 'all' );
		wp_enqueue_style( 'owl-theme', get_template_directory_uri() . '/css/owl.theme.default.min.css', array(), false, 'all' );
		wp_enqueue_style( 'swiper-carousel', get_template_directory_uri() . '/css/swiper.min.css', array(), false, 'all' );
		wp_enqueue_style( 'img-popup', get_template_directory_uri() . '/css/magnific-popup.css', array(), false, 'all' );
		wp_enqueue_style( 'animate', get_template_directory_uri() . '/css/animate.css', array(), false, 'all' );
		wp_enqueue_style( 'app7-stylesheet', get_template_directory_uri() . '/css/style.css', array(), false, 'all' );
		wp_enqueue_style( 'space-stylesheet', get_template_directory_uri() . '/css/space.css', array(), false, 'all' );
		wp_enqueue_style( 'app7-responsive', get_template_directory_uri() . '/css/responsive.css', array(), false, 'all' );
		wp_enqueue_style( 'app7-main-stylesheet', get_stylesheet_uri(), array(), false, 'all' );


		// all javascript
		wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js', array( 'jquery' ), null, true );
		wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.bundle.min.js', array( 'jquery' ), null, true );
		wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/js/owl.carousel.min.js', array( 'jquery' ), null, true );
		wp_enqueue_script( 'swiper-carousel', get_template_directory_uri() . '/js/swiper.min.js', array( 'jquery' ), null, true );
		wp_enqueue_script( 'js-nav', get_template_directory_uri() . '/js/jquery.nav.js', array( 'jquery' ), null, true );
		wp_enqueue_script( 'waypoints', get_template_directory_uri() . '/js/jquery.waypoints.js', array( 'jquery' ), null, true );
		wp_enqueue_script( 'js-waypoints', get_template_directory_uri() . '/js/jquery.waypoints.js', array( 'jquery' ), null, true );
		wp_enqueue_script( 'headroom', get_template_directory_uri() . '/js/headroom.min.js', array( 'jquery' ), null, true );
		wp_enqueue_script( 'jquery-headroom', get_template_directory_uri() . '/js/jquery.headroom.min.js', array( 'jquery' ), null, true );
		wp_enqueue_script( 'counterup', get_template_directory_uri() . '/js/jquery.counterup.min.js', array( 'jquery' ), null, true );
		wp_enqueue_script( 'wow', get_template_directory_uri() . '/js/wow.min.js', array( 'jquery' ), null, true );
		wp_enqueue_script( 'popup', get_template_directory_uri() . '/js/jquery.magnific-popup.min.js', array( 'jquery' ), null, true );
		wp_enqueue_script( 'app7-custom', get_template_directory_uri() . '/js/custom.js', array( 'jquery' ), null, true );

		$map_api = get_theme_mod( 'map_api' );
		if($map_api !=''){
			//map api
			wp_enqueue_script( 'google-map-api', 'https://maps.googleapis.com/maps/api/js?key='.$map_api, array( 'jquery' ), null, false );
		}
		

		// Load the html5 shiv.
		wp_enqueue_script( 'html5shiv', get_template_directory_uri().'/js/html5shiv.min.js', array());
		wp_script_add_data( 'html5shiv', 'conditional', 'lt IE 9');
		// Load the Respond .
		wp_enqueue_script( 'respond', get_template_directory_uri().'/js/respond.min.js', array());
		wp_script_add_data( 'respond', 'conditional', 'lt IE 9');

		// comments
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}


	}
}
add_action( 'wp_enqueue_scripts', 'app7_scripts');




/**
 * Enqueue google fonts
 */
if(!function_exists('app7_web_fonts_url')) {
	function app7_web_fonts_url($font) {
		$font_url = '';

		if ( 'off' !== _x( 'on', 'Google font: on or off', 'app7' ) ) {
			$font_url = add_query_arg( 'family', urlencode($font), "//fonts.googleapis.com/css" );
		}
		return $font_url;
	}
}	
if(!function_exists('app7_font_scripts')) {
	function app7_font_scripts() {
		wp_enqueue_style( 'app7-web-font', app7_web_fonts_url('Montserrat:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i|Open Sans:300,300i,400,400i,600,600i,700,700i,800,800i|Raleway:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i'), array());
	}
}
add_action( 'wp_enqueue_scripts', 'app7_font_scripts' );


/**
*	Post Class
*/
if(!function_exists('app7_post_class')){
	function app7_post_class($classes){
		if(is_single()){
			$classes[] = 'single-blog';
		} else {
			$classes[] = 'blog-post';
		}
		return $classes;
	}
}
add_filter( 'post_class', 'app7_post_class' );

/**
* widgets
*/
if(!function_exists('app7_widget')){
	function app7_widget(){
	  	/**
		* Main Sidebar
		*/
		register_sidebar( array(
			'name'          => esc_html__( 'Blog Sidebar', 'app7' ),
			'id'            => 'blog-sidebar',
			'description'   => esc_html__( 'Add widgets here to appear in your sidebar', 'app7' ),
			'before_widget' => '<div class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>'
		) );
		/**
		* Footer Sidebar
		*/
		register_sidebar( array(
			'name'          => esc_html__( 'Footer Sidebar', 'app7' ),
			'id'            => 'footer-sidebar',
			'description'   => esc_html__( 'Add widgets here to appear in your sidebar', 'app7' ),
			'before_widget' => '<div class="col-md-4 col-sm-12"><aside class="widget %2$s">',
			'after_widget'  => '</aside></div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>'
		) );
	}
}
add_action( 'widgets_init', 'app7_widget' );



require_once get_template_directory() . '/inc/app7_functions.php';
require_once get_template_directory() . '/inc/app7_customizer.php';